# Polars Extensions

This library is designed to extend the capabilities of polars with functionalities that are not currently found in Polars. 


## Social Proving Ground

Polars is written in Rust, but these extensions are created in pure python. The concept for this package is to create a social proving ground for extensions that could be added to the main polars library. Those who don't know Rust can develop functions here in Python and the best ideas can be passed on to the main polars library for development. 